@@ -31,11 +31,11 @@ static const my_bool MYBOOL_FALSE	= 0;
 #define DWORD unsigned long
 
 #undef UPTR
-#define UPTR unsigned long
+#define UPTR void *
 
 #undef HAS_UV64
 #if UVSIZE == 8
-#	define HAS_UV64
+#	define HAS_UV64 1
 #endif
 
 #undef XLONG
